@@ -1,7 +1,7 @@
 package Perinci::Examples::CLI;
 
-our $DATE = '2016-05-20'; # DATE
-our $VERSION = '0.72'; # VERSION
+our $DATE = '2016-06-02'; # DATE
+our $VERSION = '0.73'; # VERSION
 
 use 5.010001;
 use strict;
@@ -323,7 +323,7 @@ Perinci::Examples::CLI - Example for CLI help/usage generation
 
 =head1 VERSION
 
-This document describes version 0.72 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2016-05-20.
+This document describes version 0.73 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2016-06-02.
 
 =head1 DESCRIPTION
 
@@ -378,11 +378,11 @@ Result:
    {
      logs => [
                {
-                 file    => "/home/s1/perl5/perlbrew/perls/perl-5.22.1/lib/site_perl/5.22.1/Perinci/Access/Schemeless.pm",
+                 file    => "/home/u1/perl5/perlbrew/perls/perl-5.22.1/lib/site_perl/5.22.1/Perinci/Access/Schemeless.pm",
                  func    => "Perinci::Access::Schemeless::action_call",
                  line    => 494,
                  package => "Perinci::Access::Schemeless",
-                 time    => 1463678215,
+                 time    => 1464843388,
                  type    => "create",
                },
              ],
@@ -583,7 +583,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ex
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Examples>.
 
 =head1 BUGS
 
