@@ -1,7 +1,7 @@
 package Perinci::Examples::Tiny::Args;
 
-our $DATE = '2016-05-20'; # DATE
-our $VERSION = '0.72'; # VERSION
+our $DATE = '2016-06-02'; # DATE
+our $VERSION = '0.73'; # VERSION
 
 our %SPEC;
 
@@ -66,6 +66,56 @@ sub has_date_arg {
     }];
 }
 
+# this Rinci metadata is already normalized
+$SPEC{has_duration_arg} = {
+    v => 1.1,
+    summary => "This function contains a duration argument",
+    args => {
+        'duration' => {
+            schema => ['duration', {req=>1}, {}],
+            pos => 0,
+            req => 1,
+        },
+    },
+};
+sub has_duration_arg {
+    my %args = @_;
+    my $duration = $args{duration};
+    [200, "OK", {
+        "ref(value)" => ref($duration),
+        "value (stringified)" => "$duration",
+    }];
+}
+
+# this Rinci metadata is already normalized
+$SPEC{has_date_and_duration_args} = {
+    v => 1.1,
+    summary => "This function contains a date and a duration argument",
+    args => {
+        'date' => {
+            schema => ['date', {req=>1}, {}],
+            pos => 0,
+            req => 1,
+        },
+        'duration' => {
+            schema => ['duration', {req=>1}, {}],
+            pos => 1,
+            req => 1,
+        },
+    },
+};
+sub has_date_and_duration_args {
+    my %args = @_;
+    my $date = $args{date};
+    my $duration = $args{duration};
+    [200, "OK", {
+        "ref(date)" => ref($date),
+        "date (stringified)" => "$date",
+        "ref(duration)" => ref($duration),
+        "duration (stringified)" => "$duration",
+    }];
+}
+
 1;
 # ABSTRACT: Tests related to function arguments
 
@@ -81,12 +131,12 @@ Perinci::Examples::Tiny::Args - Tests related to function arguments
 
 =head1 VERSION
 
-This document describes version 0.72 of Perinci::Examples::Tiny::Args (from Perl distribution Perinci-Examples), released on 2016-05-20.
+This document describes version 0.73 of Perinci::Examples::Tiny::Args (from Perl distribution Perinci-Examples), released on 2016-06-02.
 
 =head1 DESCRIPTION
 
-Like th other Perinci::Examples::Tiny::*, this module does not use other modules
-and is suitable for testing Perinci::CmdLine::Inline as well as other
+Like the other Perinci::Examples::Tiny::*, this module does not use other
+modules and is suitable for testing Perinci::CmdLine::Inline as well as other
 Perinci::CmdLine frameworks.
 
 =head1 FUNCTIONS
@@ -118,6 +168,34 @@ that contains extra information.
 Return value:  (any)
 
 
+=head2 has_date_and_duration_args(%args) -> [status, msg, result, meta]
+
+This function contains a date and a duration argument.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<date>* => I<date>
+
+=item * B<duration>* => I<duration>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 has_date_arg(%args) -> [status, msg, result, meta]
 
 This function contains a date argument.
@@ -171,13 +249,39 @@ that contains extra information.
 
 Return value: Return the two numbers multiplied (any)
 
+
+=head2 has_duration_arg(%args) -> [status, msg, result, meta]
+
+This function contains a duration argument.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<duration>* => I<duration>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Examples>.
 
 =head1 BUGS
 
